@@ -2,6 +2,8 @@ from typing import Any, final
 
 
 class Singleton(type):
+    """A metaclass that creates a singleton class."""
+
     _instances = dict[Any, Any]()
 
     def __call__(cls, *args: Any, **kwargs: Any) -> Any:
@@ -12,8 +14,11 @@ class Singleton(type):
 
 @final
 class UnsetType(metaclass=Singleton):
+    """Used to represent an unset optional parameter."""
+
     def __repr__(self) -> str:
         return __name__ + ".Unset"
 
 
 Unset = UnsetType()
+"""Used to represent an unset optional parameter."""
